@@ -123,10 +123,10 @@ uid_t getuid ();
 #include "version.h"
 
 /* The default PATH for simulated logins to non-superuser accounts.  */
-#define DEFAULT_LOGIN_PATH ":/usr/ucb:/bin:/usr/bin"
+#define DEFAULT_LOGIN_PATH "/usr/local/bin:/usr/bin:/bin:/usr/bin/X11:."
 
 /* The default PATH for simulated logins to superuser accounts.  */
-#define DEFAULT_ROOT_LOGIN_PATH "/usr/ucb:/bin:/usr/bin:/etc"
+#define DEFAULT_ROOT_LOGIN_PATH "/sbin:/bin:/usr/sbin:/usr/bin:/usr/bin/X11:/usr/local/sbin:/usr/local/bin"
 
 /* The shell to run if none is given in the user's passwd entry.  */
 #define DEFAULT_SHELL "/bin/sh"
@@ -378,6 +378,9 @@ modify_environment (pw, shell)
     {
       /* Set HOME, SHELL, and if not becoming a super-user,
 	 USER and LOGNAME.  */
+      /* Also, set PATH to DEFAULT_ROOT_LOGIN_PATH if becoming a
+         super-user, so that /sbin and /usr/sbin are correctly in
+         PATH. --imurdock */
       if (change_environment)
 	{
 	  xputenv (concat ("HOME", "=", pw->pw_dir));
@@ -387,6 +390,12 @@ modify_environment (pw, shell)
 	      xputenv (concat ("USER", "=", pw->pw_name));
 	      xputenv (concat ("LOGNAME", "=", pw->pw_name));
 	    }
+	  else
+	    {
+	      xputenv (concat ("PATH", "=", pw->pw_uid
+			       ? DEFAULT_LOGIN_PATH
+			       : DEFAULT_ROOT_LOGIN_PATH));
+	    }
 	}
     }
 }
